Template
========

.. currentmodule:: dash_component_template.template

.. autoclass:: Template
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Template.id
      ~Template.layout

   .. rubric:: Methods Summary

   .. autosummary::

      ~Template.after_setup_layout
      ~Template.before_setup_layout
      ~Template.child
      ~Template.grid
      ~Template.setup_layout

   .. rubric:: Attributes Documentation

   .. autoattribute:: id
   .. autoattribute:: layout

   .. rubric:: Methods Documentation

   .. automethod:: after_setup_layout
   .. automethod:: before_setup_layout
   .. automethod:: child
   .. automethod:: grid
   .. automethod:: setup_layout
